@@ -53,6 +53,8 @@ class SaveFile:
             :obj:`functions <pyrogram.api.functions>` (i.e: a Telegram API method you wish to use which is not
             available yet in the Client class as an easy-to-use method).
 
+        .. include:: /_includes/usable-by/users-bots.rst
+
         Parameters:
             path (``str`` | ``BinaryIO``):
                 The path of the file you want to upload that exists on your local machine or a binary file-like object
@@ -125,8 +127,10 @@ class SaveFile:
         if file_size == 0:
             raise ValueError("File size equals to 0 B")
 
-        if file_size > 2000 * 1024 * 1024:
-            raise ValueError("Telegram doesn't support uploading files bigger than 2000 MiB")
+        file_size_limit_mib = 4000 if self.me.is_premium else 2000
+
+        if file_size > file_size_limit_mib * 1024 * 1024:
+            raise ValueError(f"Can't upload files bigger than {file_size_limit_mib} MiB")
 
         file_total_parts = int(math.ceil(file_size / part_size))
         is_big = file_size > 10 * 1024 * 1024
